@@ -37,6 +37,7 @@
 
 /*** DOCUMENTATION
 	<application name="If" language="en_US">
+		<since><version>18.16.0</version><version>20.1.0</version></since>
 		<synopsis>
 			Start an if branch.
 		</synopsis>
@@ -57,6 +58,7 @@
 		</see-also>
 	</application>
 	<application name="ElseIf" language="en_US">
+		<since><version>18.16.0</version><version>20.1.0</version></since>
 		<synopsis>
 			Start an else if branch.
 		</synopsis>
@@ -78,6 +80,7 @@
 		</see-also>
 	</application>
 	<application name="Else" language="en_US">
+		<since><version>18.16.0</version><version>20.1.0</version></since>
 		<synopsis>
 			Define an optional else branch.
 		</synopsis>
@@ -96,6 +99,7 @@
 		</see-also>
 	</application>
 	<application name="EndIf" language="en_US">
+		<since><version>18.16.0</version><version>20.1.0</version></since>
 		<synopsis>
 			End an if branch.
 		</synopsis>
@@ -111,6 +115,7 @@
 		</see-also>
 	</application>
 	<application name="ExitIf" language="en_US">
+		<since><version>18.16.0</version><version>20.1.0</version></since>
 		<synopsis>
 			End an If branch.
 		</synopsis>
@@ -286,9 +291,11 @@ static int if_helper(struct ast_channel *chan, const char *data, int end)
 		snprintf(end_varname,sizeof(end_varname),"END_%s",varname);
 		ast_channel_lock(chan);
 		/* For EndIf, simply go to the next priority.
+		 * We do not add 1 to ast_channel_priority because the dialplan will
+		 * auto-increment the priority when we return, so just keep the priority as is.
 		 * For ExitIf or false If() condition, we need to find the end of the current
 		 * If branch (at same indentation) and branch there. */
-		endifpri = end == 2 ? ast_channel_priority(chan) + 1 : find_matching_endif(chan, NULL);
+		endifpri = end == 2 ? ast_channel_priority(chan) : find_matching_endif(chan, NULL);
 		if ((goto_str = pbx_builtin_getvar_helper(chan, end_varname))) {
 			ast_parseable_goto(chan, goto_str);
 			pbx_builtin_setvar_helper(chan, end_varname, NULL);
