@@ -42,6 +42,7 @@
 
 /*** DOCUMENTATION
 	<application name="SpeechCreate" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Create a Speech Structure.
 		</synopsis>
@@ -56,6 +57,7 @@
 		</description>
 	</application>
 	<application name="SpeechActivateGrammar" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Activate a grammar.
 		</synopsis>
@@ -70,6 +72,7 @@
 		</description>
 	</application>
 	<application name="SpeechStart" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Start recognizing voice in the audio stream.
 		</synopsis>
@@ -81,6 +84,7 @@
 		</description>
 	</application>
 	<application name="SpeechBackground" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Play a sound file and wait for speech to be recognized.
 		</synopsis>
@@ -105,6 +109,9 @@
 					<option name="n">
 						<para>Don't answer the channel if it has not already been answered.</para>
 					</option>
+					<option name="p">
+						<para>Return partial results when backend is terminated by timeout.</para>
+					</option>
 				</optionlist>
 			</parameter>
 		</syntax>
@@ -121,6 +128,7 @@
 		</description>
 	</application>
 	<application name="SpeechDeactivateGrammar" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Deactivate a grammar.
 		</synopsis>
@@ -135,6 +143,7 @@
 		</description>
 	</application>
 	<application name="SpeechProcessingSound" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Change background processing sound.
 		</synopsis>
@@ -148,6 +157,7 @@
 		</description>
 	</application>
 	<application name="SpeechDestroy" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			End speech recognition.
 		</synopsis>
@@ -160,6 +170,7 @@
 		</description>
 	</application>
 	<application name="SpeechLoadGrammar" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Load a grammar.
 		</synopsis>
@@ -173,6 +184,7 @@
 		</description>
 	</application>
 	<application name="SpeechUnloadGrammar" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Unload a grammar.
 		</synopsis>
@@ -185,6 +197,7 @@
 		</description>
 	</application>
 	<function name="SPEECH_SCORE" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Gets the confidence score of a result.
 		</synopsis>
@@ -197,6 +210,7 @@
 		</description>
 	</function>
 	<function name="SPEECH_TEXT" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Gets the recognized text of a result.
 		</synopsis>
@@ -209,6 +223,7 @@
 		</description>
 	</function>
 	<function name="SPEECH_GRAMMAR" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Gets the matched grammar of a result if available.
 		</synopsis>
@@ -221,6 +236,7 @@
 		</description>
 	</function>
 	<function name="SPEECH_ENGINE" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Get or change a speech engine specific attribute.
 		</synopsis>
@@ -232,6 +248,7 @@
 		</description>
 	</function>
 	<function name="SPEECH_RESULTS_TYPE" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Sets the type of results that will be returned.
 		</synopsis>
@@ -241,6 +258,7 @@
 		</description>
 	</function>
 	<function name="SPEECH" language="en_US">
+		<since><version>1.6.1.0</version></since>
 		<synopsis>
 			Gets information about speech recognition results.
 		</synopsis>
@@ -700,10 +718,12 @@ static int speech_streamfile(struct ast_channel *chan, const char *filename, con
 
 enum {
 	SB_OPT_NOANSWER = (1 << 0),
+	SB_OPT_PARTIALRESULTS = (1 << 1),
 };
 
 AST_APP_OPTIONS(speech_background_options, BEGIN_OPTIONS
 	AST_APP_OPTION('n', SB_OPT_NOANSWER),
+	AST_APP_OPTION('p', SB_OPT_PARTIALRESULTS),
 END_OPTIONS );
 
 /*! \brief SpeechBackground(Sound File,Timeout) Dialplan Application */
@@ -933,7 +953,10 @@ static int speech_background(struct ast_channel *chan, const char *data)
 		}
 	}
 
-	if (!ast_strlen_zero(dtmf)) {
+	if (ast_strlen_zero(dtmf) && speech->state == AST_SPEECH_STATE_READY && ast_test_flag(&options, SB_OPT_PARTIALRESULTS)) {
+		/* Copy to speech structure the results, even partial ones, if desired and available */
+		speech->results = ast_speech_results_get(speech);
+	} else if (!ast_strlen_zero(dtmf)) {
 		/* We sort of make a results entry */
 		speech->results = ast_calloc(1, sizeof(*speech->results));
 		if (speech->results != NULL) {
