@@ -57,6 +57,7 @@ struct ast_channel_id {
 	time_t creation_time;				/*!< Creation time */
 	int creation_unique;				/*!< sub-second unique value */
 	char unique_id[AST_MAX_UNIQUEID];	/*!< Unique Identifier */
+	char tenant_id[AST_MAX_TENANT_ID];	/*!< Multi-tenant identifier */
 };
 
 /*!
@@ -94,7 +95,6 @@ struct ast_channel {
 	struct ast_cdr *cdr;				/*!< Call Detail Record */
 	struct ast_tone_zone *zone;			/*!< Tone zone as set in indications.conf or
 							 *   in the CHANNEL dialplan function */
-	struct ast_channel_monitor *monitor;		/*!< Channel monitoring */
 	ast_callid callid;			/*!< Bound call identifier pointer */
 	struct ao2_container *dialed_causes;		/*!< Contains tech-specific and Asterisk cause data from dialed channels */
 
@@ -178,7 +178,6 @@ struct ast_channel {
 	enum ast_channel_state state;			/*!< State of line -- Don't write directly, use ast_setstate() */
 	int rings;					/*!< Number of rings so far */
 	int priority;					/*!< Dialplan: Current extension priority */
-	int macropriority;				/*!< Macro: Current non-macro priority. See app_macro.c */
 	int amaflags;					/*!< Set BEFORE PBX is started to determine AMA flags */
 	enum ast_channel_adsicpe adsicpe;		/*!< Whether or not ADSI is detected on CPE */
 	unsigned int fin;				/*!< Frames in counters. The high bit is a debug mask, so
@@ -208,8 +207,6 @@ struct ast_channel {
 	char exten[AST_MAX_EXTENSION];			/*!< Dialplan: Current extension number */
 	char lastcontext[AST_MAX_CONTEXT];		/*!< Dialplan: Previous extension context */
 	char lastexten[AST_MAX_EXTENSION];		/*!< Dialplan: Previous extension number */
-	char macrocontext[AST_MAX_CONTEXT];		/*!< Macro: Current non-macro context. See app_macro.c */
-	char macroexten[AST_MAX_EXTENSION];		/*!< Macro: Current non-macro extension. See app_macro.c */
 	char unbridged;							/*!< non-zero if the bridge core needs to re-evaluate the current
 											 bridging technology which is in use by this channel's bridge. */
 	char is_t38_active;						/*!< non-zero if T.38 is active on this channel. */
@@ -316,6 +313,21 @@ const char *ast_channel_linkedid(const struct ast_channel *chan)
 	return chan->linkedid.unique_id;
 }
 
+const char *ast_channel_tenantid(const struct ast_channel *chan)
+{
+	/* It's ok for tenantid to be empty, so no need to assert */
+	return chan->linkedid.tenant_id;
+}
+
+void ast_channel_tenantid_set(struct ast_channel *chan, const char *value)
+{
+	if (ast_strlen_zero(value)) {
+		return;
+	}
+	ast_copy_string(chan->linkedid.tenant_id, value, sizeof(chan->linkedid.tenant_id));
+	ast_channel_snapshot_invalidate_segment(chan, AST_CHANNEL_SNAPSHOT_INVALIDATE_BASE);
+}
+
 const char *ast_channel_appl(const struct ast_channel *chan)
 {
 	return chan->appl;
@@ -377,22 +389,6 @@ void ast_channel_exten_set(struct ast_channel *chan, const char *value)
 	ast_copy_string(chan->exten, value, sizeof(chan->exten));
 	ast_channel_snapshot_invalidate_segment(chan, AST_CHANNEL_SNAPSHOT_INVALIDATE_DIALPLAN);
 }
-const char *ast_channel_macrocontext(const struct ast_channel *chan)
-{
-	return chan->macrocontext;
-}
-void ast_channel_macrocontext_set(struct ast_channel *chan, const char *value)
-{
-	ast_copy_string(chan->macrocontext, value, sizeof(chan->macrocontext));
-}
-const char *ast_channel_macroexten(const struct ast_channel *chan)
-{
-	return chan->macroexten;
-}
-void ast_channel_macroexten_set(struct ast_channel *chan, const char *value)
-{
-	ast_copy_string(chan->macroexten, value, sizeof(chan->macroexten));
-}
 
 char ast_channel_dtmf_digit_to_emulate(const struct ast_channel *chan)
 {
@@ -451,14 +447,6 @@ void ast_channel_hangupcause_set(struct ast_channel *chan, int value)
 	chan->hangupcause = value;
 	ast_channel_snapshot_invalidate_segment(chan, AST_CHANNEL_SNAPSHOT_INVALIDATE_HANGUP);
 }
-int ast_channel_macropriority(const struct ast_channel *chan)
-{
-	return chan->macropriority;
-}
-void ast_channel_macropriority_set(struct ast_channel *chan, int value)
-{
-	chan->macropriority = value;
-}
 int ast_channel_priority(const struct ast_channel *chan)
 {
 	return chan->priority;
@@ -631,14 +619,6 @@ void ast_channel_masqr_set(struct ast_channel *chan, struct ast_channel *value)
 {
 	chan->masqr = value;
 }
-struct ast_channel_monitor *ast_channel_monitor(const struct ast_channel *chan)
-{
-	return chan->monitor;
-}
-void ast_channel_monitor_set(struct ast_channel *chan, struct ast_channel_monitor *value)
-{
-	chan->monitor = value;
-}
 struct ast_filestream *ast_channel_stream(const struct ast_channel *chan)
 {
 	return chan->stream;
@@ -1350,7 +1330,8 @@ static int pvt_cause_cmp_fn(void *obj, void *vstr, int flags)
 
 #define DIALED_CAUSES_BUCKETS 37
 
-struct ast_channel *__ast_channel_internal_alloc(void (*destructor)(void *obj), const struct ast_assigned_ids *assignedids, const struct ast_channel *requestor, const char *file, int line, const char *function)
+struct ast_channel *__ast_channel_internal_alloc_with_initializers(void (*destructor)(void *obj), const struct ast_assigned_ids *assignedids,
+	const struct ast_channel *requestor, const struct ast_channel_initializers *initializers, const char *file, int line, const char *function)
 {
 	struct ast_channel *tmp;
 
@@ -1371,6 +1352,20 @@ struct ast_channel *__ast_channel_internal_alloc(void (*destructor)(void *obj),
 		return ast_channel_unref(tmp);
 	}
 
+	/* Check initializers validity here for early abort. Unfortunately, we can't do much here because
+	 * tenant ID is part of linked ID, which would overwrite it further down. */
+	if (initializers) {
+		if (initializers->version == 0) {
+			ast_log(LOG_ERROR, "Channel initializers must have a non-zero version.\n");
+			return ast_channel_unref(tmp);
+		} else if (initializers->version != AST_CHANNEL_INITIALIZERS_VERSION) {
+			ast_log(LOG_ERROR, "ABI mismatch for ast_channel_initializers. "
+				"Please ensure all modules were compiled for "
+				"this version of Asterisk.\n");
+			return ast_channel_unref(tmp);
+		}
+	}
+
 	/* set the creation time in the uniqueid */
 	tmp->uniqueid.creation_time = time(NULL);
 	tmp->uniqueid.creation_unique = ast_atomic_fetchadd_int(&uniqueint, 1);
@@ -1396,6 +1391,12 @@ struct ast_channel *__ast_channel_internal_alloc(void (*destructor)(void *obj),
 		tmp->linkedid = tmp->uniqueid;
 	}
 
+	/* Things like tenant ID need to be set here, otherwise they would be overwritten by
+	 * things like inheriting linked ID above. */
+	if (initializers) {
+		ast_copy_string(tmp->linkedid.tenant_id, initializers->tenantid, sizeof(tmp->linkedid.tenant_id));
+	}
+
 	AST_VECTOR_INIT(&tmp->fds, AST_MAX_FDS);
 
 	/* Force all channel snapshot segments to be created on first use, so we don't have to check if
@@ -1406,6 +1407,12 @@ struct ast_channel *__ast_channel_internal_alloc(void (*destructor)(void *obj),
 	return tmp;
 }
 
+struct ast_channel *__ast_channel_internal_alloc(void (*destructor)(void *obj), const struct ast_assigned_ids *assignedids,
+	const struct ast_channel *requestor, const char *file, int line, const char *function)
+{
+	return __ast_channel_internal_alloc_with_initializers(destructor, assignedids, requestor, NULL, file, line, function);
+}
+
 struct ast_channel *ast_channel_internal_oldest_linkedid(struct ast_channel *a, struct ast_channel *b)
 {
 	ast_assert(a->linkedid.creation_time != 0);
