@@ -36,6 +36,7 @@ static struct stasis_message_router *bridge_state_router;
 /*** DOCUMENTATION
 	<managerEvent language="en_US" name="BridgeCreate">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since><version>12.0.0</version></since>
 			<synopsis>Raised when a bridge is created.</synopsis>
 			<syntax>
 				<bridge_snapshot/>
@@ -49,6 +50,7 @@ static struct stasis_message_router *bridge_state_router;
 	</managerEvent>
 	<managerEvent language="en_US" name="BridgeDestroy">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since><version>12.0.0</version></since>
 			<synopsis>Raised when a bridge is destroyed.</synopsis>
 			<syntax>
 				<bridge_snapshot/>
@@ -62,6 +64,7 @@ static struct stasis_message_router *bridge_state_router;
 	</managerEvent>
 	<managerEvent language="en_US" name="BridgeEnter">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since><version>12.0.0</version></since>
 			<synopsis>Raised when a channel enters a bridge.</synopsis>
 			<syntax>
 				<bridge_snapshot/>
@@ -79,6 +82,7 @@ static struct stasis_message_router *bridge_state_router;
 	</managerEvent>
 	<managerEvent language="en_US" name="BridgeLeave">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since><version>12.0.0</version></since>
 			<synopsis>Raised when a channel leaves a bridge.</synopsis>
 			<syntax>
 				<bridge_snapshot/>
@@ -93,6 +97,7 @@ static struct stasis_message_router *bridge_state_router;
 	</managerEvent>
 	<managerEvent language="en_US" name="BridgeVideoSourceUpdate">
 		<managerEventInstance class="EVENT_FLAG_CALL">
+			<since><version>13.13.0</version><version>14.2.0</version></since>
 			<synopsis>Raised when the channel that is the source of video in a bridge changes.</synopsis>
 			<syntax>
 				<bridge_snapshot/>
@@ -107,6 +112,9 @@ static struct stasis_message_router *bridge_state_router;
 		</managerEventInstance>
 	</managerEvent>
 	<manager name="BridgeList" language="en_US">
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Get a list of bridges in the system.
 		</synopsis>
@@ -127,6 +135,9 @@ static struct stasis_message_router *bridge_state_router;
 		</see-also>
 	</manager>
 	<manager name="BridgeInfo" language="en_US">
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Get information about a bridge.
 		</synopsis>
@@ -149,6 +160,7 @@ static struct stasis_message_router *bridge_state_router;
 			<list-elements>
 				<managerEvent language="en_US" name="BridgeInfoChannel">
 					<managerEventInstance class="EVENT_FLAG_COMMAND">
+						<since><version>13.0.0</version></since>
 						<synopsis>Information about a channel in a bridge.</synopsis>
 						<syntax>
 							<channel_snapshot/>
@@ -158,6 +170,7 @@ static struct stasis_message_router *bridge_state_router;
 			</list-elements>
 			<managerEvent language="en_US" name="BridgeInfoComplete">
 				<managerEventInstance class="EVENT_FLAG_COMMAND">
+					<since><version>13.0.0</version></since>
 					<synopsis>Information about a bridge.</synopsis>
 					<syntax>
 						<bridge_snapshot/>
@@ -167,6 +180,9 @@ static struct stasis_message_router *bridge_state_router;
 		</responses>
 	</manager>
 	<manager name="BridgeDestroy" language="en_US">
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Destroy a bridge.
 		</synopsis>
@@ -188,6 +204,9 @@ static struct stasis_message_router *bridge_state_router;
 		</see-also>
 	</manager>
 	<manager name="BridgeKick" language="en_US">
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Kick a channel from a bridge.
 		</synopsis>
@@ -378,6 +397,7 @@ static void bridge_merge_cb(void *data, struct stasis_subscription *sub,
 	/*** DOCUMENTATION
 		<managerEvent language="en_US" name="BridgeMerge">
 			<managerEventInstance class="EVENT_FLAG_CALL">
+				<since><version>16.24.0</version><version>18.10.0</version><version>19.2.0</version></since>
 				<synopsis>Raised when two bridges are merged.</synopsis>
 				<syntax>
 					<bridge_snapshot prefix="To"/>
