@@ -29,7 +29,7 @@
  * \author George Joseph <george.joseph@fairview5.com>
   */
 
-/*! \li \ref res_phoneprov.c uses the configuration file \ref phoneprov.conf and \ref users.conf and \ref sip.conf
+/*! \li \ref res_phoneprov.c uses the configuration file \ref phoneprov.conf and \ref users.conf
  * \addtogroup configuration_file Configuration Files
  */
 
@@ -87,6 +87,7 @@
 
 /*** DOCUMENTATION
 	<function name="PP_EACH_EXTENSION" language="en_US">
+		<since><version>1.6.2.0</version></since>
 		<synopsis>
 			Execute specified template for each extension.
 		</synopsis>
@@ -99,6 +100,7 @@
 		</description>
 	</function>
 	<function name="PP_EACH_USER" language="en_US">
+		<since><version>1.6.2.0</version></since>
 		<synopsis>
 			Generate a string for each phoneprov user.
 		</synopsis>
@@ -1250,11 +1252,6 @@ static struct varshead *get_defaults(void)
 	}
 
 	value = ast_variable_retrieve(phoneprov_cfg, "general", pp_general_lookup[AST_PHONEPROV_STD_SERVER_PORT]);
-	if (!value) {
-		if ((cfg = ast_config_load("sip.conf", config_flags)) && cfg != CONFIG_STATUS_FILEINVALID) {
-			value = ast_variable_retrieve(cfg, "general", "bindport");
-		}
-	}
 	var = ast_var_assign(variable_lookup[AST_PHONEPROV_STD_SERVER_PORT], S_OR(value, "5060"));
 	if (cfg && cfg != CONFIG_STATUS_FILEINVALID) {
 		ast_config_destroy(cfg);
@@ -1400,7 +1397,7 @@ static int unload_module(void)
 	ast_custom_function_unregister(&pp_each_extension_function);
 	ast_cli_unregister_multiple(pp_cli, ARRAY_LEN(pp_cli));
 
-	/* This cleans up the sip.conf/users.conf provider (called specifically for clarity) */
+	/* This cleans up the users.conf provider (called specifically for clarity) */
 	ast_phoneprov_provider_unregister(SIPUSERS_PROVIDER_NAME);
 
 	/* This cleans up the framework which also cleans up the providers. */
@@ -1465,9 +1462,9 @@ static int load_module(void)
 		goto error;
 	}
 
-	/* Register ourselves as the provider for sip.conf/users.conf */
+	/* Register ourselves as the provider for users.conf */
 	if (ast_phoneprov_provider_register(SIPUSERS_PROVIDER_NAME, load_users)) {
-		ast_log(LOG_WARNING, "Unable register sip/users config provider.  Others may succeed.\n");
+		ast_log(LOG_WARNING, "Unable register users config provider.  Others may succeed.\n");
 	}
 
 	ast_http_uri_link(&phoneprovuri);
